#!/usr/bin/env python

"""Provides validation and count utilities for pyAvroPhonetic

-------------------------------------------------------------------------------

Copyright (C) 2013 Kaustav Das Modak <kaustav.dasmodak@yahoo.co.in.

This file is part of pyAvroPhonetic.

pyAvroPhonetic is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

pyAvroPhonetic is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with pyAvroPhonetic.  If not, see <http://www.gnu.org/licenses/>.

"""


# Imports
from pyavrophonetic import config


class Validate:
    """Provides validation methods for pyAvroPhonetic"""

    def __init__(self):
        """Initialize the Validate class"""
        # Provide easy access to last fixed string
        self.fixed_string = ''

    def is_vowel(self, text):
        """Check if given string is a vowel"""
        if text.lower().encode('utf-8') in config.AVRO_VOWELS:
            return True
        else:
            return False

    def is_consonant(self, text):
        """Check if given string is a consonant"""
        if text.lower().encode('utf-8') in config.AVRO_CONSONANTS:
            return True
        else:
            return False

    def is_number(self, text):
        """Check if given string is a number"""
        if text.lower().encode('utf-8') in config.AVRO_NUMBERS:
            return True
        else:
            return False

    def is_punctuation(self, text):
        """Check if given string is a punctuation"""
        text = text.lower().encode('utf-8')
        if (text in config.AVRO_VOWELS or
            text in config.AVRO_CONSONANTS or
            text in config.AVRO_NUMBERS):
            return False
        else:
            return True

    def is_case_sensitive(self, text):
        """Check if given string is case sensitive"""
        if text.lower().encode('utf-8') in config.AVRO_CASESENSITIVES:
            return True
        else:
            return False

    def fix_string(self, text):
        """Implement fix string method"""
        fixed = []
        for i in text:
            if self.is_case_sensitive(i):
                fixed.append(i)
            else:
                fixed.append(i.lower())
        self.fixed_string = ''.join(fixed)
        return self.fixed_string


class Count:
    """Provides methods for counting certain occurrences in string"""

    def __init__(self):
        """Initialize Count class"""
        # Provide easy access to last count number
        self.count = 0

    def count_vowels(self, text):
        """Count number of occurrences of vowels in a given string"""
        count = 0
        for i in text:
            if i in config.AVRO_VOWELS:
                count += 1
        self.count = count
        return count

    def count_consonants(self, text):
        """Count number of occurrences of consonants in a given string"""
        count = 0
        for i in text:
            if i in config.AVRO_CONSONANTS:
                count += 1
        self.count = count
        return count



#!/usr/bin/env python

"""Provides configurations for pyAvroPhonetic

-------------------------------------------------------------------------------

Copyright (C) 2013 Kaustav Das Modak <kaustav.dasmodak@yahoo.co.in.

This file is part of pyAvroPhonetic.

pyAvroPhonetic is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

pyAvroPhonetic is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with pyAvroPhonetic.  If not, see <http://www.gnu.org/licenses/>.

"""


# Imports
import os
import json


# Constants
# -- Path to current directory
BASE_PATH = os.path.dirname(__file__)
# -- path to avrodict.json
AVRO_DICT_FILE = os.path.abspath(os.path.join(BASE_PATH,
                                              "resources/avrodict.json"))
# -- Loads json data from avrodict.json
AVRO_DICT = json.load(open(AVRO_DICT_FILE))
# -- Shortcut to vowels
AVRO_VOWELS = set(AVRO_DICT['data']['vowel'])
# -- Shortcut to consonants
AVRO_CONSONANTS = set(AVRO_DICT['data']['consonant'])
# -- Shortcut to case-sensitives
AVRO_CASESENSITIVES = set(AVRO_DICT['data']['casesensitive'])
# -- Shortcut to number
AVRO_NUMBERS = set(AVRO_DICT['data']['number'])



#!/usr/bin/env python

from distutils.core import setup
from pyavrophonetic import __version__

setup(name='PyAvroPhonetic',
      version=__version__,
      description='Python implementation of Avro Phonetic',
      long_description=open('README.rst', 'rt').read(),
      author='Kaustav Das Modak',
      author_email='kaustav.dasmodak@yahoo.co.in',
      url='https://github.com/kaustavdm/pyAvroPhonetic',
      packages=['pyavrophonetic',],
      license='GNU GPL v3 or later',
      classifiers=[
        'Development Status :: 1 - Planning',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 or later (GPLv3+)',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 2.6',
        'Programming Language :: Python :: 2.7',
        ]
      )



#!/usr/bin/env python

"""Provides the main library for Avro Phonetic

-------------------------------------------------------------------------------

Copyright (C) 2013 Kaustav Das Modak <kaustav.dasmodak@yahoo.co.in.

This file is part of pyAvroPhonetic.

pyAvroPhonetic is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

pyAvroPhonetic is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with pyAvroPhonetic.  If not, see <http://www.gnu.org/licenses/>.

"""

# Imports
from pyavrophonetic.utils import Validate

# Instantiate
validate = Validate()

def parse(text):
    """Parse text input and produce Bengali output"""
    # TODO: Add code here. I do nothing presently.
    return text
